@@ -74,3 +74,13 @@ def check_vars2():
     a = b = c = 5
     print '%(a)d %(b)d' % vars(c)
 
+def check_modulo_1():
+  print '%s' % '1'
+  print '%s' % 1
+  print .55555 % 1
+  print 55555 % 1
+  f = 55555.55 
+  print f % 1
+
+def check_bad_format_end_percent(arg):
+  print 'ha, better not crash %' % arg
