@@ -2,7 +2,7 @@
 
 def x():
     # these are broken, this is BAD code!!!
-    i = ~~ 10
+    i = ~~ (10)
     while i > 0 :
       --i
     while i < 100 :
@@ -21,3 +21,8 @@ def y():
     # should generate a warning
     print ("format w/2 strings %s" + "=" + "'%s'") % ('a', 'b', 'c')
 
+def z():
+    i = -5
+    print +i, i, -i
+    print +5, 5, -5
+
