@@ -3,8 +3,8 @@
 __pychecker__ = 'no-classdoc'
 
 class Abstract:
-    def f(self): raise SystemError("override in subclass")
-    def g(self): raise KeyError("override in subclass")
+    def f(self): raise NotImplementedError, "override in subclass"
+    def g(self): raise NotImplementedError
 class ConcreteBad(Abstract):
     def g(self): pass
 class ConcreteGood(ConcreteBad):
@@ -13,6 +13,14 @@ a = Abstract()                          # error
 cb = ConcreteBad()                      # error
 cg = ConcreteGood()                     # ok, f defined
 
+class ConcreteInst:
+    def f(self): raise SystemError("not yet ready for prime time")
+ch = ConcreteInst()                     # ok, raises SystemError
+
+class AbstractInst:
+    def f(self): raise NotImplementedError("not yet ready for prime time")
+ch = AbstractInst()
+
 cb.g()
 def f():
     class MoreBad(Abstract):
