@@ -19,6 +19,22 @@ def x(a):
         print 'True'
     if a != false:
         print 'false'
+    if a is 'false':
+        print 'false'
+    if a is 'True':
+        print 'True'
+    if a is 53343:
+        print '53343'
+    if a is 1e7:
+        print '1e7'
+    if a is not 'false':
+        print 'false'
+    if a is not 'True':
+        print 'True'
+    if a is not 53343:
+        print '53343'
+    if a is not 1e7:
+        print '1e7'
 
 def y(a):
     'should not warn'
@@ -26,10 +42,10 @@ def y(a):
         print 'True'
     if a is not false:
         print 'false'
-    if a is 'false':
-        print 'false'
-    if a is 'True':
-        print 'True'
+    if a == 53343:
+        print '53343'
+    if a == 1e7:
+        print '1e7'
     if a == 'TRUE' or \
        a == 'True' or \
        a == 'true':
